let socket;
let trackingAktiv = false;
let isConnected = false;
let distraktions;

function connectWebSocket() {
    if (isConnected) {
        console.log("Bereits verbunden.");
        return;
    }

    // Versuche, eine Verbindung herzustellen
    socket = new WebSocket("ws://localhost:8080");

    // Timeout für die Verbindung (z.B. 5 Sekunden)
    let connectionTimeout = setTimeout(() => {
        console.log("Verbindung timeout, Server reagiert nicht.");
        socket.close();  // Schließt den WebSocket
        isConnected = false; // Setzt isConnected auf false
    }, 5000); // Timeout nach 5 Sekunden

    socket.onopen = function() {
        console.log("Verbunden mit der WPF-Anwendung.");
        clearTimeout(connectionTimeout);
        isConnected = true; // Markiere als verbunden
        socket.send("Hallo vom Addon");
    };

    // Empfang von Nachrichten
    socket.onmessage = function(event) {
        const message = parseMessage(event.data);
        console.log("Nachricht empfangen: ", message);
        //navigator.clipboard.writeText(message);

        if(message.action === "sendJsonContent") {
           //navigator.clipboard.writeText(message);
           distraktions = createDistractionList(message);
        }

        if (message.action === "startTracking" && message.status === true) {
            console.log("Tracking gestartet.");
            addTabListeners();
            trackingAktiv = true;
        } else if (message.action === "stopTracking" && message.status === false) {
            console.log("Tracking gestoppt.");
            removeTabListeners();
            trackingAktiv = false;
        }
    };

    socket.onclose = function() {
        console.log("Verbindung geschlossen.");
        isConnected = false;
        // Versuche, nach einer kurzen Zeit erneut eine Verbindung herzustellen
        setTimeout(connectWebSocket, 5000); // 5 Sekunden warten, bevor erneut versucht wird
    };

    socket.onerror = function(error) {
        console.error("WebSocket Fehler:", error);
        socket.close(); // Schließe den Socket, um den Fehler zu behandeln und es erneut zu versuchen
    };

}

connectWebSocket();
addTabListeners();

function createDistractionList(message) {
    const result = {};
    for (content in message) {
        const distractingUrls = message["content"]["Games"].filter(item => item.distracting).map(item => item.url);
        
        if (distractingUrls.length > 0) {
            result[content] = distractingUrls;
        }
    }
    return result;
}

function parseMessage(message) {
    try {
        return JSON.parse(message);
    } catch {
        return message;
    }
}


// Funktion zum Hinzufügen der Event-Listener
function addTabListeners() {
    browser.tabs.onCreated.addListener(handleTabCreated);
    browser.tabs.onUpdated.addListener(handleTabUpdated);
    browser.tabs.onActivated.addListener(handlerTabActiv);
    console.log("Tab-Listener hinzugefügt.");
}

// Funktion zum Entfernen der Event-Listener
function removeTabListeners() {
    browser.tabs.onCreated.removeListener(handleTabCreated);
    browser.tabs.onUpdated.removeListener(handleTabUpdated);
    browser.tabs.onActivated.removeListener(handlerTabActiv);
    console.log("Tab-Listener entfernt.");
}

function handleTabCreated(tab) {
    checkUrl(tab.url, tab.tabId);
};


function handleTabUpdated(tabId, changeInfo, tab) {
    if (changeInfo.status === 'complete') {
        checkUrl(tab.url, tabId);
    }
};

function handlerTabActiv(activeInfo) {
    browser.tabs.get(activeInfo.tabId).then((tab) => {
        checkUrl(tab.url, tab.tabId);
    });
}


function checkUrl(url, tabId) {
    for (content in distraktions.content) {
    //const content = "youtube.com";
        if (url.includes(distraktions["content"][content])) {
            socket.send(`Distraktion Bemerkt: ${url}`);

            browser.tabs.query({ active: true, currentWindow: true }).then((tabs) => {
                const activeTab = tabs[0];
                browser.tabs.sendMessage(activeTab.id, { action: "showOverlay", tabId: tabId });
            });
        }
    }
};