﻿using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using static InnoLabProjektDektopApp.DistractionsList;
using System.Text.Json;
using System.Text.RegularExpressions;
using System.IO;
using System.Collections.Generic;
using System.Diagnostics;

namespace InnoLabProjektDektopApp
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class Distractions : Page
    {

        private string jsonFilePath = System.IO.Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "Assets", "distractingWebsites.json");
        private Dictionary<string, List<WebsiteEntry>> ?data;
        public Distractions()
        {
            InitializeComponent();
            LoadJsonData();
            this.MouseDown += ClosePopupOnClickOutside;
        }



       


        private void CheckBox_Changed(object sender, RoutedEventArgs e)
        {
            if (sender is CheckBox checkBox && checkBox.Tag is (string category, WebsiteEntry entry))
            {
                entry.IsDistracting = checkBox.IsChecked ?? false;
                SaveJsonData(); // Save changes back to JSON
            }
        }

        private void SearchBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            if (data == null || data.Count == 0)
            {
                MessageBox.Show("No data found. Please ensure the JSON is loaded correctly.");
                return;
            }

            string searchText = SearchBox.Text.Trim().ToLower();

            // Wenn das Suchfeld leer ist, blende sowohl Placeholder als auch das Panel aus
            if (string.IsNullOrEmpty(searchText))
            {
                SearchPlaceholder.Visibility = Visibility.Visible; // Placeholder anzeigen
                SearchResultsPanelContainer.Visibility = Visibility.Collapsed; // Suchergebnisse ausblenden
                return;
            }

            // Wenn Text vorhanden ist, blende den Placeholder aus und zeige das Panel
            SearchPlaceholder.Visibility = Visibility.Collapsed;
            SearchResultsPanelContainer.Visibility = Visibility.Visible;

            // Vorherige Suchergebnisse löschen
            SearchResultsPanel.Children.Clear();

            bool hasResults = false;

            // Durchsuche alle Kategorien und URLs
            foreach (var category in data)
            {
                foreach (var entry in category.Value)
                {
                    if (entry.Url.ToLower().Contains(searchText))
                    {
                        hasResults = true;

                        // StackPanel für jedes Suchergebnis erstellen
                        var resultPanel = new StackPanel { Orientation = Orientation.Horizontal, Margin = new Thickness(5) };

                        // CheckBox erstellen
                        var checkBox = new CheckBox
                        {
                            IsChecked = entry.IsDistracting,
                            Margin = new Thickness(5),
                            VerticalAlignment = VerticalAlignment.Center,
                            Tag = (category.Key, entry) // Speichert Kategorie und Eintrag
                        };
                        checkBox.Checked += CheckBox_Changed;
                        checkBox.Unchecked += CheckBox_Changed;

                        // URL als Text anzeigen
                        var urlText = new TextBlock
                        {
                            Text = entry.Url,
                            Margin = new Thickness(10, 0, 0, 0),
                            VerticalAlignment = VerticalAlignment.Center
                        };

                        // Kategorie als grauen Text anzeigen
                        var categoryText = new TextBlock
                        {
                            Text = $"[{category.Key}]",
                            Margin = new Thickness(10, 0, 0, 0),
                            VerticalAlignment = VerticalAlignment.Center,
                            Foreground = Brushes.Gray
                        };

                        // Elemente zum Ergebnis-Panel hinzufügen
                        resultPanel.Children.Add(checkBox);
                        resultPanel.Children.Add(urlText);
                        resultPanel.Children.Add(categoryText);

                        // Panel zur Anzeige der Suchergebnisse hinzufügen
                        SearchResultsPanel.Children.Add(resultPanel);
                    }
                }
            }

            // Falls keine Ergebnisse gefunden wurden, "No results found." anzeigen
            if (!hasResults)
            {
                var noResultsText = new TextBlock
                {
                    Text = "No results found.",
                    FontSize = 16,
                    FontWeight = FontWeights.Bold,
                    Foreground = Brushes.Gray,
                    HorizontalAlignment = HorizontalAlignment.Center,
                    Margin = new Thickness(10)
                };

                SearchResultsPanel.Children.Add(noResultsText);
            }
        }




        private void LoadJsonData()
        {
            try
            {
                string jsonContent = File.ReadAllText(jsonFilePath);
                data = JsonSerializer.Deserialize<Dictionary<string, List<WebsiteEntry>>>(jsonContent) ?? new();
            }
            catch (Exception ex)
            {
                MessageBox.Show($"Error loading JSON: {ex.Message}");
                data = new();
            }
        }

        private void AddButton_Click(object sender, RoutedEventArgs e)
        {
            string enteredUrl = UrlInputBox.Text.Trim();
            string selectedCategory = (CategoryList.SelectedItem as ListBoxItem)?.Content?.ToString();

            // Validate category selection
            if (string.IsNullOrEmpty(selectedCategory))
            {
                MessageBox.Show("Please select a category.", "Invalid Category", MessageBoxButton.OK, MessageBoxImage.Warning);
                return;
            }

            // Add new entry to the category
            if (!data.ContainsKey(selectedCategory))
            {
                data[selectedCategory] = new List<WebsiteEntry>();
            }

            data[selectedCategory].Add(new WebsiteEntry
            {
                Url = enteredUrl,
                IsDistracting = true
            });

            // Save changes to JSON
            SaveJsonData();
            MessageBox.Show($"URL '{enteredUrl}' added to category '{selectedCategory}'.", "Success", MessageBoxButton.OK, MessageBoxImage.Information);

            // Clear input fields
            UrlInputBox.Clear();
            CategoryList.SelectedIndex = -1; // Auswahl zurücksetzen
            SelectedText.Text = "Select Category"; // Den Text im UI zurücksetzen
        }




        private void SaveJsonData()
        {
            try
            {
                string jsonContent = JsonSerializer.Serialize(data, new JsonSerializerOptions { WriteIndented = true });
                File.WriteAllText(jsonFilePath, jsonContent);
            }
            catch (Exception ex)
            {
                MessageBox.Show($"Error saving JSON: {ex.Message}");
            }
        }

        private void TextBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            // Hier kannst du Logik hinzufügen, die bei einer Änderung im Textfeld ausgeführt werden soll.
            // Zum Beispiel:
            var textBox = sender as TextBox;
            if (textBox != null)
            {
                string inputText = textBox.Text;
                // Debug-Ausgabe oder Logik basierend auf inputText
                System.Diagnostics.Debug.WriteLine($"TextBox geändert: {inputText}");
            }
        }

        private void UrlInputBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            // Überprüfen, ob die TextBox leer ist
            if (!string.IsNullOrEmpty(UrlInputBox.Text))
            {
                UrlPlaceholder.Visibility = Visibility.Collapsed; // Placeholder ausblenden
            }
            else
            {
                UrlPlaceholder.Visibility = Visibility.Visible; // Placeholder anzeigen
            }
        }

       private void TogglePopup(object sender, MouseButtonEventArgs e)
{
    // Popup umschalten
    PopupMenu.IsOpen = !PopupMenu.IsOpen;

    // Wenn das Popup geöffnet wird, registriere das globale Klick-Event
    if (PopupMenu.IsOpen)
    {
        this.PreviewMouseDown += ClosePopupOnClickOutside;
    }
}

private void CategoryList_SelectionChanged(object sender, SelectionChangedEventArgs e)
{
    if (CategoryList.SelectedItem is ListBoxItem selectedItem)
    {
        SelectedText.Text = selectedItem.Content.ToString();
        PopupMenu.IsOpen = false; // Popup schließen nach Auswahl
        this.PreviewMouseDown -= ClosePopupOnClickOutside; // Event entfernen
    }
}

private void ClosePopupOnClickOutside(object sender, MouseButtonEventArgs e)
{
    if (!PopupMenu.IsMouseOver && !DropdownBorder.IsMouseOver)
    {
        PopupMenu.IsOpen = false;
        this.PreviewMouseDown -= ClosePopupOnClickOutside; // Event entfernen
    }
}




        private void NavigateToDistractionList(object sender, RoutedEventArgs e)
        {
            var clickedButton = sender as Border;

            if (clickedButton != null)
            {
                // Kategorie aus Tag lesen
                string category = clickedButton.DataContext?.ToString();

                if (!string.IsNullOrEmpty(category))
                {
                    if(category == "Other Programs")
                    {
                        this.NavigationService.Navigate(new ProgramsList());
                    }
                    else
                    {
                        this.NavigationService.Navigate(new DistractionsList(category));
                    }
                }
            }
        }


        private void Border_PreviewMouseDown(object sender, MouseButtonEventArgs e)
        {
            var border = sender as Border;
            if (border != null && border.Child is Grid grid)
            {
                Debug.WriteLine("Das ist ein Log-Eintrag.");

                var checkbox = grid.Children.OfType<CheckBox>().FirstOrDefault();
                if (checkbox != null)
                {
                    checkbox.IsChecked = !checkbox.IsChecked;
                    e.Handled = true; // Verhindert, dass andere Elemente das Event blockieren
                }
            }
        }


        private void PreviousPage_Click(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Progress());
        }

        private void NextPage_Click(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Settings());
        }
    }
}
