﻿using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text.Json;
using System.Text.Json.Serialization;


namespace InnoLabProjektDektopApp
{
    public partial class DistractionsList : Page
    {
        private string _category;
        private Dictionary<string, List<WebsiteEntry>> _data;
        private string _jsonFilePath;

        public DistractionsList(string category)
        {
            InitializeComponent();
            _category = category;
            _jsonFilePath = System.IO.Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "Assets", "distractingWebsites.json");
            LoadCategoryItems();
        }

        private void SearchBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            // Platzhalter ein- oder ausblenden
            if (!string.IsNullOrEmpty(SearchBox.Text))
            {
                SearchPlaceholder.Visibility = Visibility.Collapsed; // Ausblenden
            }
            else
            {
                SearchPlaceholder.Visibility = Visibility.Visible; // Einblenden
            }

            // Filterlogik für die Suchergebnisse
            string searchText = SearchBox.Text?.ToLower() ?? string.Empty;

            // Clear current UI
            ItemsPanel.Children.Clear();

            // Filter items based on search text
            if (_data != null && _data.ContainsKey(_category))
            {
                var filteredItems = _data[_category]
                    .Where(item => string.IsNullOrEmpty(searchText) || item.Url.ToLower().Contains(searchText))
                    .ToList();

                foreach (var item in filteredItems)
                {
                    // Create a StackPanel for each filtered item
                    var stackPanel = new StackPanel { Orientation = Orientation.Horizontal, Margin = new Thickness(5, 2, 5, 2) };

                    var checkBox = new CheckBox
                    {
                        Content = item.Url,
                        Margin = new Thickness(5),
                        IsChecked = item.IsDistracting,
                        Tag = item
                    };

                    checkBox.Checked += CheckBox_CheckedChanged;
                    checkBox.Unchecked += CheckBox_CheckedChanged;

                    var deleteButtonBorder = new Border
                    {
                        Style = (Style)Application.Current.Resources["RoundedButtonBorder"],
                        Child = new TextBlock
                        {
                            Text = "Delete",
                            HorizontalAlignment = HorizontalAlignment.Center,
                            VerticalAlignment = VerticalAlignment.Center,
                            Foreground = (Brush)Application.Current.Resources["BACKGROUND_PRIMARY_BRUSH"],
                            FontWeight = FontWeights.Bold
                        },
                        Margin = new Thickness(5, 0, 10, 0),
                        Cursor = Cursors.Hand,
                        Width = 50,
                        Height = 30,
                        CornerRadius = new CornerRadius(10)
                    };
                    deleteButtonBorder.MouseDown += (s, e) => DeleteItemInList(item);

                    stackPanel.Children.Add(checkBox);
                    stackPanel.Children.Add(deleteButtonBorder);

                    // Add the filtered StackPanel to ItemsPanel
                    ItemsPanel.Children.Add(stackPanel);
                }
            }
        }



        private void AddButton_Click(object sender, RoutedEventArgs e)
        {
            string enteredUrl = UrlInputBox.Text.Trim();

            if (string.IsNullOrEmpty(enteredUrl))
            {
                MessageBox.Show("Please enter a URL.", "Invalid Input", MessageBoxButton.OK, MessageBoxImage.Warning);
                return;
            }

            // Add the new URL to the current category
            if (!_data.ContainsKey(_category))
            {
                _data[_category] = new List<WebsiteEntry>();
            }

            _data[_category].Add(new WebsiteEntry
            {
                Url = enteredUrl,
                IsDistracting = true
            });

            // Save changes to the JSON
            SaveData();

            // Add to UI dynamically
            var stackPanel = new StackPanel { Orientation = Orientation.Horizontal, Margin = new Thickness(5, 2, 5, 2) };

            var checkBox = new CheckBox
            {
                Content = enteredUrl,
                Margin = new Thickness(5),
                IsChecked = true,
                Tag = new WebsiteEntry { Url = enteredUrl, IsDistracting = true }
            };

            checkBox.Checked += CheckBox_CheckedChanged;
            checkBox.Unchecked += CheckBox_CheckedChanged;

            stackPanel.Children.Add(checkBox);
            ItemsPanel.Children.Add(stackPanel);

            MessageBox.Show($"URL '{enteredUrl}' has been added to the '{_category}' category.", "Success", MessageBoxButton.OK, MessageBoxImage.Information);

            // Clear the input field
            UrlInputBox.Clear();
        }


        private void UrlInputBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            // Überprüfen, ob die TextBox leer ist
            if (!string.IsNullOrEmpty(UrlInputBox.Text))
            {
                UrlPlaceholder.Visibility = Visibility.Collapsed; // Placeholder ausblenden
            }
            else
            {
                UrlPlaceholder.Visibility = Visibility.Visible; // Placeholder anzeigen
            }
        }

        private void LoadCategoryItems()
        {
            try
            {
                // JSON-Datei lesen
                string jsonContent = File.ReadAllText(_jsonFilePath);

                // JSON deserialisieren
                _data = JsonSerializer.Deserialize<Dictionary<string, List<WebsiteEntry>>>(jsonContent);

                if (_data != null && _data.ContainsKey(_category))
                {
                    // Kategorie-Elemente laden
                    var items = _data[_category];
                    foreach (var item in items)
                    {
                        // Checkbox erstellen
                        var stackPanel = new StackPanel { Orientation = Orientation.Horizontal, Margin = new Thickness(5, 2, 5, 2) };

                        var checkBox = new CheckBox
                        {
                            Content = item.Url,
                            Margin = new Thickness(5),
                            IsChecked = item.IsDistracting,
                            Tag = item // Speichert die Referenz zum Item
                        };

                        checkBox.Checked += CheckBox_CheckedChanged;
                        checkBox.Unchecked += CheckBox_CheckedChanged;

                        var deleteButtonBorder = new Border
                        {
                            Style = (Style)Application.Current.Resources["RoundedButtonBorder"],
                            Child = new TextBlock
                            {
                                Text = "Delete",
                                HorizontalAlignment = HorizontalAlignment.Center,
                                VerticalAlignment = VerticalAlignment.Center,
                                Foreground = (Brush)Application.Current.Resources["BACKGROUND_PRIMARY_BRUSH"],
                                FontWeight = FontWeights.Bold
                            },
                            Margin = new Thickness(5, 0, 10, 0),
                            Cursor = Cursors.Hand,
                            Width = 50,
                            Height = 30,
                            CornerRadius = new CornerRadius(10)
                        };
                        deleteButtonBorder.MouseDown += (s, e) => DeleteItemInList(item);

                        stackPanel.Children.Add(checkBox);
                        stackPanel.Children.Add(deleteButtonBorder);

                        // Elemente zur Liste hinzufügen
                        ItemsPanel.Children.Add(stackPanel);
                    }

                    // Überschrift setzen
                    HeaderTextBlock.Text = _category;
                }
                else
                {
                    MessageBox.Show($"No items found for category '{_category}'.");
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show($"Error loading items: {ex.Message}");
            }
        }

        private void CheckBox_CheckedChanged(object sender, RoutedEventArgs e)
        {
            if (sender is CheckBox checkBox && checkBox.Tag is WebsiteEntry item)
            {
                // Wert in der JSON-Datenstruktur aktualisieren
                item.IsDistracting = checkBox.IsChecked ?? false;

                // Änderungen in die Datei schreiben
                SaveData();
            }
        }

        private void DeleteItemInList(WebsiteEntry websiteEntry)
        {
            if (MessageBox.Show($"Are you sure you want to delete '{websiteEntry.Url}'?", "Delete Item", MessageBoxButton.YesNo, MessageBoxImage.Question) == MessageBoxResult.Yes)
            {
                // Remove the item from the list
                _data[_category].Remove(websiteEntry);
                // Save changes to the JSON
                SaveData();
                // Remove the item from the UI
                var itemStackPanel = ItemsPanel.Children.OfType<StackPanel>().FirstOrDefault(sp => sp.Children.OfType<CheckBox>().Any(cb => cb.Tag == websiteEntry));
                if (itemStackPanel != null)
                {
                    ItemsPanel.Children.Remove(itemStackPanel);
                }
            }
        }

        private void SaveData()
        {
            try
            {
                string updatedJson = JsonSerializer.Serialize(_data, new JsonSerializerOptions { WriteIndented = true });
                File.WriteAllText(_jsonFilePath, updatedJson);
                MessageBox.Show("Data saved successfully!");
            }
            catch (Exception ex)
            {
                MessageBox.Show($"Error saving data: {ex.Message}");
            }
        }
        /*
        private void BackButton_Click(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Distractions());
        }
        */

        public class WebsiteEntry
        {
            [JsonPropertyName("url")]
            public string Url { get; set; }

            [JsonPropertyName("distracting")]
            public bool IsDistracting { get; set; }
        }
    }
}