﻿using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.IO;
using System.Text.Json;
using System.Text.RegularExpressions;


namespace InnoLabProjektDektopApp
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class Settings : Page
    {
        public Settings()
        {
            InitializeComponent();
            MascotVisibilityChanged(null, null);
        }
        private void MascotVisibilityChanged(object sender, RoutedEventArgs e)
        {
            if (MotivationSection == null)
                return; // Beende die Methode, wenn MotivationSection noch nicht existiert.

            if (MascotVisibleNo.IsChecked == true)
            {
                MotivationSection.Visibility = Visibility.Collapsed; // Hide the section

                //uncheck motivation options
                WordsOfAffirmationCheckBox.IsChecked = false;
                InsultingWordsCheckBox.IsChecked = false;
            }
            else
            {
                MotivationSection.Visibility = Visibility.Visible; // Show the section
            }
        }



        private void TextBox_TextChanged(object sender, TextChangedEventArgs e)
        {

        }

        private void TextBox_TextChanged_1(object sender, TextChangedEventArgs e)
        {

        }



        private void SaveSettings()
        {
            // Sammle die Werte aus den ComboBoxen oder verwende Standardwerte
            string focusPeriod = string.IsNullOrWhiteSpace(SelectedText2.Text) ? "45" : SelectedText2.Text;
            string breakPeriod = string.IsNullOrWhiteSpace(SelectedText3.Text) ? "45" : SelectedText3.Text;
            string cycles = string.IsNullOrWhiteSpace(SelectedText4.Text) ? "4" : SelectedText4.Text;

            string distractionMode = DistractionModeFullBlocking.IsChecked == true
        ? "Full-blocking mode"
        : DistractionModeMascotFeedback.IsChecked == true
            ? "Mascot feedback only"
            : "seconds warning mode";

            string warningSeconds = !string.IsNullOrWhiteSpace(SelectedText.Text)
     ? SelectedText.Text
     : "10";

            string mascotVisible = MascotVisibleYes.IsChecked == true ? "Yes" : "No";

            bool wordsOfAffirmation = WordsOfAffirmationCheckBox.IsChecked ?? false;
            bool insultingWords = InsultingWordsCheckBox.IsChecked ?? false;

            // JSON-Datei erstellen
            var settings = new Dictionary<string, Dictionary<string, string>>
    {
        {
            "profile1",
            new Dictionary<string, string>
            {
                { "focusPeriod", focusPeriod },
                { "breakPeriod", breakPeriod },
                { "cycles", cycles },
                { "distractionMode", distractionMode },
                { "warningSeconds", warningSeconds },
                { "mascotVisibility", mascotVisible },
                { "wordsOfAffirmation", wordsOfAffirmation.ToString() },
                { "insultingWords", insultingWords.ToString() }
            }
        }
    };

            string filePath = System.IO.Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "settings.json");

            // JSON speichern
            File.WriteAllText(filePath, JsonSerializer.Serialize(settings, new JsonSerializerOptions { WriteIndented = true }));

            // Nach dem Speichern: JSON lesen und in der MessageBox anzeigen
            if (File.Exists(filePath))
            {
                string jsonContent = File.ReadAllText(filePath);
                var savedSettings = JsonSerializer.Deserialize<Dictionary<string, Dictionary<string, string>>>(jsonContent);

                if (savedSettings != null && savedSettings.ContainsKey("profile1"))
                {
                    var profileSettings = savedSettings["profile1"];

                    string message = "Saved Settings for profile1:\n";
                    foreach (var setting in profileSettings)
                    {
                        message += $"{setting.Key}: {setting.Value}\n";
                    }

                    MessageBox.Show(message, "Saved Settings", MessageBoxButton.OK, MessageBoxImage.Information);
                }
            }
        }

        private void PreviousPage_Click(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Distractions());
        }

        private void NextPage_Click(object sender, RoutedEventArgs e)
        {
            SaveSettings();
            this.NavigationService.Navigate(new Overview());
        }

        private void TogglePopup(object sender, MouseButtonEventArgs e)
        {
            // Popup umschalten
            PopupMenu.IsOpen = !PopupMenu.IsOpen;

            // Wenn das Popup geöffnet wird, registriere das globale Klick-Event
            if (PopupMenu.IsOpen)
            {
                this.PreviewMouseDown += ClosePopupOnClickOutside;
            }
        }

        private void CategoryList_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (CategoryList.SelectedItem is ListBoxItem selectedItem)
            {
                SelectedText.Text = selectedItem.Content.ToString();
                PopupMenu.IsOpen = false; // Popup schließen nach Auswahl
                this.PreviewMouseDown -= ClosePopupOnClickOutside; // Event entfernen
            }
        }

        private void ClosePopupOnClickOutside(object sender, MouseButtonEventArgs e)
        {
            if (!PopupMenu.IsMouseOver && !DropdownBorder.IsMouseOver)
            {
                PopupMenu.IsOpen = false;
                this.PreviewMouseDown -= ClosePopupOnClickOutside; // Event entfernen
            }
        }

        private void TogglePopup2(object sender, MouseButtonEventArgs e)
        {
            // Popup umschalten
            PopupMenu2.IsOpen = !PopupMenu2.IsOpen;

            // Wenn das Popup geöffnet wird, registriere das globale Klick-Event
            if (PopupMenu2.IsOpen)
            {
                this.PreviewMouseDown += ClosePopupOnClickOutside2;
            }
        }

        private void CategoryList_SelectionChanged2(object sender, SelectionChangedEventArgs e)
        {
            if (CategoryList2.SelectedItem is ListBoxItem selectedItem)
            {
                SelectedText2.Text = selectedItem.Content.ToString();
                PopupMenu2.IsOpen = false; // Popup schließen nach Auswahl
                this.PreviewMouseDown -= ClosePopupOnClickOutside2; // Event entfernen
            }
        }

        private void SelectedTextBox2_TextChanged(object sender, TextChangedEventArgs e)
        {
            TextBox textBox = sender as TextBox;
            if (textBox == null) return;

            string input = textBox.Text;

            // Erlaubt nur numerische Eingaben (positive Ganzzahlen) und begrenzt die Länge auf 3 Zeichen
            if (!Regex.IsMatch(input, @"^\d*$"))
            {
                int cursorPos = textBox.SelectionStart - 1; // Cursor-Position speichern
                textBox.Text = Regex.Replace(input, @"\D", ""); // Alle nicht-numerischen Zeichen entfernen
                textBox.SelectionStart = Math.Max(cursorPos, 0); // Cursor wieder an die ursprüngliche Stelle setzen
            }

            // Maximal 3 Zeichen erlauben
            if (textBox.Text.Length > 3)
            {
                int cursorPos = textBox.SelectionStart - 1; // Cursor-Position speichern
                textBox.Text = textBox.Text.Substring(0, 3); // Kürzt den Text auf 3 Zeichen
                textBox.SelectionStart = Math.Max(cursorPos, 0); // Cursor-Position wieder setzen
            }
        }



        private void ClosePopupOnClickOutside2(object sender, MouseButtonEventArgs e)
        {
            if (!PopupMenu2.IsMouseOver && !DropdownBorder2.IsMouseOver)
            {
                PopupMenu2.IsOpen = false;
                this.PreviewMouseDown -= ClosePopupOnClickOutside; // Event entfernen
            }
        }

        private void TogglePopup3(object sender, MouseButtonEventArgs e)
        {
            // Popup umschalten
            PopupMenu3.IsOpen = !PopupMenu2.IsOpen;

            // Wenn das Popup geöffnet wird, registriere das globale Klick-Event
            if (PopupMenu3.IsOpen)
            {
                this.PreviewMouseDown += ClosePopupOnClickOutside3;
            }
        }

        private void CategoryList_SelectionChanged3(object sender, SelectionChangedEventArgs e)
        {
            if (CategoryList3.SelectedItem is ListBoxItem selectedItem)
            {
                SelectedText3.Text = selectedItem.Content.ToString();
                PopupMenu3.IsOpen = false; // Popup schließen nach Auswahl
                this.PreviewMouseDown -= ClosePopupOnClickOutside3; // Event entfernen
            }
        }



        private void ClosePopupOnClickOutside3(object sender, MouseButtonEventArgs e)
        {
            if (!PopupMenu3.IsMouseOver && !DropdownBorder2.IsMouseOver)
            {
                PopupMenu3.IsOpen = false;
                this.PreviewMouseDown -= ClosePopupOnClickOutside; // Event entfernen
            }
        }

        private void TogglePopup4(object sender, MouseButtonEventArgs e)
        {
            // Popup umschalten
            PopupMenu4.IsOpen = !PopupMenu2.IsOpen;

            // Wenn das Popup geöffnet wird, registriere das globale Klick-Event
            if (PopupMenu4.IsOpen)
            {
                this.PreviewMouseDown += ClosePopupOnClickOutside4;
            }
        }

        private void CategoryList_SelectionChanged4(object sender, SelectionChangedEventArgs e)
        {
            if (CategoryList4.SelectedItem is ListBoxItem selectedItem)
            {
                SelectedText4.Text = selectedItem.Content.ToString();
                PopupMenu4.IsOpen = false; // Popup schließen nach Auswahl
                this.PreviewMouseDown -= ClosePopupOnClickOutside4; // Event entfernen
            }
        }



        private void ClosePopupOnClickOutside4(object sender, MouseButtonEventArgs e)
        {
            if (!PopupMenu4.IsMouseOver && !DropdownBorder2.IsMouseOver)
            {
                PopupMenu4.IsOpen = false;
                this.PreviewMouseDown -= ClosePopupOnClickOutside; // Event entfernen
            }
        }


    }
}