﻿using InnoLabProjektDektopApp.Screens.Regulaer;
using InnoLabProjektDektopApp.Services;
using InnoLabProjektDektopApp.Services.WebSocketServer;
using System.IO;
using System.Net.Sockets;
using System.Text.Json;
using System.Text.RegularExpressions;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;

namespace InnoLabProjektDektopApp
{
    /// <summary>
    /// Interaction logic for Overview.xaml
    /// </summary>
    public partial class Overview : Page
    {
        // Aktuelles Profil, für das Einstellungen geladen werden sollen
        private string profile = "profile1";

        // Pfad zur JSON-Datei, in der die Einstellungen gespeichert sind
        private string SettingsFilePath;

        private static Session tmpSession = null;

        public Overview()
        {
            InitializeComponent();

            // Definieren des Pfads zur JSON-Datei
            this.SettingsFilePath = System.IO.Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "settings.json");

            // Einstellungen für das aktuelle Profil laden
            LoadSettings();
        }

        public static Session getSession() {
            return tmpSession;
        }

        // Methode, um die Einstellungen für das aktuelle Profil aus der JSON-Datei zu laden
        private void LoadSettings()
        {
            try
            {
                // JSON-Datei lesen
                // JSON-Datei lesen
                if (File.Exists(SettingsFilePath))
                {
                    string jsonContent = File.ReadAllText(SettingsFilePath);
                    var settings = JsonSerializer.Deserialize<Dictionary<string, JsonElement>>(jsonContent);

                    if (settings != null && settings.ContainsKey(profile))
                    {
                        var profileSettings = settings[profile];

                        // Focus Period
                        if (profileSettings.TryGetProperty("focusPeriod", out var focusPeriodElement))
                        {
                            string focusPeriod = focusPeriodElement.GetString() ?? "45";

                            // Setze den geladenen Wert in das Textfeld (SelectedText1)
                            SelectedText1.Text = focusPeriod;

                            // Falls der geladene Wert mit einem ListBoxItem übereinstimmt, markiere es
                            foreach (ListBoxItem item in CategoryList1.Items)
                            {
                                if (item.Content.ToString() == focusPeriod)
                                {
                                    CategoryList1.SelectedItem = item;
                                    break;
                                }
                            }
                        }


                        // Break Period
                        if (profileSettings.TryGetProperty("breakPeriod", out var breakPeriodElement))
                        {
                            string breakPeriod = breakPeriodElement.GetString() ?? "10";

                            // Setze den geladenen Wert in das Textfeld
                            SelectedText2.Text = breakPeriod;

                            // Falls der geladene Wert mit einem ListBoxItem übereinstimmt, markiere es
                            foreach (ListBoxItem item in CategoryList2.Items)
                            {
                                if (item.Content.ToString() == breakPeriod)
                                {
                                    CategoryList2.SelectedItem = item;
                                    break;
                                }
                            }
                        }

                        // Cycles
                        if (profileSettings.TryGetProperty("cycles", out var cyclesElement))
                        {
                            string cycles = cyclesElement.GetString() ?? "4";

                            // Setze den geladenen Wert in das Textfeld
                            SelectedText3.Text = cycles;

                            // Falls der geladene Wert mit einem ListBoxItem übereinstimmt, markiere es
                            foreach (ListBoxItem item in CategoryList3.Items)
                            {
                                if (item.Content.ToString() == cycles)
                                {
                                    CategoryList3.SelectedItem = item;
                                    break;
                                }
                            }
                        }

                        // Distraction Mode
                        
                        if (profileSettings.TryGetProperty("distractionMode", out var distractionModeElement))
                        {
                            string distractionMode = distractionModeElement.GetString() ?? "Full-blocking mode";


                            // Setze den geladenen Wert in das Textfeld
                            SelectedText.Text = distractionMode;

                            // Falls der geladene Wert mit einem ListBoxItem übereinstimmt, markiere es
                            foreach (ListBoxItem item in CategoryList.Items)
                            {
                                if (item.Content.ToString() == distractionMode)
                                {
                                    CategoryList.SelectedItem = item;
                                    break;
                                }
                            }

                            // Zusätzliche ComboBox für Sekunden aktivieren, wenn Modus "seconds warning mode" ist
                            if (distractionMode == "seconds warning mode")
                            {
                                SecondsWarningPanel.Visibility = Visibility.Visible;                              
                            }

                        }


                        // Get information about warning seconds
                        if (profileSettings.TryGetProperty("warningSeconds", out var warningSecondsElement))
                        {
                            string warningSeconds = warningSecondsElement.GetString();

                            // Überprüfen, ob der gespeicherte Wert in der ListBox vorhanden ist
                            var item = CategoryList4.Items
                                .OfType<ListBoxItem>()
                                .FirstOrDefault(i => i.Content.ToString() == warningSeconds);

                            if (item != null)
                            {
                                // Falls der Wert in der Liste existiert, setze ihn als Auswahl
                                SelectedText4.Text = item.Content.ToString();
                            }
                            else
                            {
                                // Falls der gespeicherte Wert ungültig ist oder nicht gefunden wurde, Standardwert setzen
                                SelectedText4.Text = "10"; // Standard: "10"
                            }
                        }


                        // Mascot Visibility
                        if (profileSettings.TryGetProperty("mascotVisibility", out var mascotVisibilityElement))
                        {
                            string mascotVisibility = mascotVisibilityElement.GetString();

                            // Setze den geladenen Wert in das Textfeld
                            SelectedText5.Text = mascotVisibility;

                            // Falls der geladene Wert mit einem ListBoxItem übereinstimmt, markiere es
                            foreach (ListBoxItem item in CategoryList5.Items)
                            {
                                if (item.Content.ToString() == mascotVisibility)
                                {
                                    CategoryList5.SelectedItem = item;
                                    break;
                                }
                            }

                            // Überprüfen, ob es "No" ist
                            if (mascotVisibility == "No")
                            {
                                MotivationOptionsPanel.Visibility = Visibility.Collapsed;
                            }
                            else
                            {
                                MotivationOptionsPanel.Visibility = Visibility.Visible;
                            }
                        }


                        // Checkbox: Words of Affirmation
                        if (profileSettings.TryGetProperty("wordsOfAffirmation", out var wordsOfAffirmationElement))
                        {
                            // Convert String to Boolean explicitly
                            WordsOfAffirmationCheckBox.IsChecked = bool.TryParse(wordsOfAffirmationElement.GetString(), out var result) && result;
                        }

                        // Checkbox: Insulting Words
                        if (profileSettings.TryGetProperty("insultingWords", out var insultingWordsElement))
                        {
                            // Convert String to Boolean explicitly
                            InsultingWordsCheckBox.IsChecked = bool.TryParse(insultingWordsElement.GetString(), out var result) && result;
                        }
                    }
                    else
                    {
                        MessageBox.Show($"No settings found for profile '{profile}'", "Info", MessageBoxButton.OK, MessageBoxImage.Information);
                    }
                }
                else
                {
                    MessageBox.Show($"Settings file not found at '{SettingsFilePath}'", "Error", MessageBoxButton.OK, MessageBoxImage.Error);
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show($"Error loading settings: {ex.Message}", "Error", MessageBoxButton.OK, MessageBoxImage.Error);
            }
        }


        // Hilfsmethode, um ein Element in der ComboBox basierend auf dem Inhalt zu finden
        private ComboBoxItem FindComboBoxItem(ComboBox comboBox, string content)
        {
            foreach (ComboBoxItem item in comboBox.Items)
            {
                if (item.Content.ToString() == content)
                {
                    return item;
                }
            }
            return null;
        }

        // Ereignis-Handler für den "Edit Profile"-Button
        private void EditProfile_Click(object sender, RoutedEventArgs e)
        {
            var distractions = new Distractions();
            this.NavigationService.Navigate(distractions);
        }

        // Ereignis-Handler für den "Add Profile"-Button
        private void AddProfile_Click(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("Add Profile clicked!");
        }

        // Ereignis-Handler, um den Placeholder für das Textfeld anzuzeigen oder auszublenden
        private void FocusTopicInputBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            if (!string.IsNullOrEmpty(FocusTopicInputBox.Text))
            {
                FocusTopicPlaceholder.Visibility = Visibility.Collapsed;
            }
            else
            {
                FocusTopicPlaceholder.Visibility = Visibility.Visible;
            }
        }

        // Ereignis-Handler für den "Start"-Button
        private void StartButton_Click(object sender, RoutedEventArgs e)
        {
            Server.Instance.SendMessageToAllClients("{\"action\": \"startTracking\", \"status\": true}");

            try
            {
                string jsonContent = File.ReadAllText("F:\\Dokumente\\Schule\\Studium\\InoLab\\procrastinator\\InnoLabProjektDektopApp\\InnoLabProjektDektopApp\\Assets\\distractingWebsites.json");
                //string message = $"{{\"action\": \"sendJsonContent\", \"status\": true, \"content\": {jsonContent}}}";

                // Erstelle ein Objekt für die Nachricht
                var messageObject = new
                {
                    action = "sendJsonContent",
                    status = true,
                    content = JsonSerializer.Deserialize<object>(jsonContent) // Parse den JSON-Inhalt
                };

                // Serialisiere das Objekt zu einem JSON-String
                string message = JsonSerializer.Serialize(messageObject);

                Server.Instance.SendMessageToAllClients(message);
            }
            catch
            {

            }




            // Werte auslesen
            int focusPeriod;

            // Prüfe zuerst, ob die TextBox (`SelectedText1`) eine gültige Zahl enthält
            if (int.TryParse(SelectedText1.Text, out focusPeriod))
            {
                // Wert aus der TextBox wurde erfolgreich als Ganzzahl geparst
            }
            else if (CategoryList1.SelectedItem is ListBoxItem selectedItem &&
                     int.TryParse(selectedItem.Content.ToString(), out focusPeriod))
            {
                // Falls die TextBox leer ist, prüfe ob ein Wert in der ListBox ausgewählt wurde
            }
            else
            {
                // Falls nichts gültiges eingegeben wurde, setze den Standardwert 50
                focusPeriod = 50;
            }

            // Werte auslesen
            int breakPeriod;

            // Prüfe zuerst, ob die TextBox (`SelectedText1`) eine gültige Zahl enthält
            if (int.TryParse(SelectedText2.Text, out breakPeriod))
            {
                // Wert aus der TextBox wurde erfolgreich als Ganzzahl geparst
            }
            else if (CategoryList2.SelectedItem is ListBoxItem selectedItem &&
                     int.TryParse(selectedItem.Content.ToString(), out breakPeriod))
            {
                // Falls die TextBox leer ist, prüfe ob ein Wert in der ListBox ausgewählt wurde
            }
            else
            {
                // Falls nichts gültiges eingegeben wurde, setze den Standardwert 50
                breakPeriod = 10;
            }

            // Werte auslesen
            int cycles;

            // Prüfe zuerst, ob die TextBox (`SelectedText1`) eine gültige Zahl enthält
            if (int.TryParse(SelectedText3.Text, out cycles))
            {
                // Wert aus der TextBox wurde erfolgreich als Ganzzahl geparst
            }
            else if (CategoryList3.SelectedItem is ListBoxItem selectedItem &&
                     int.TryParse(selectedItem.Content.ToString(), out cycles))
            {
                // Falls die TextBox leer ist, prüfe ob ein Wert in der ListBox ausgewählt wurde
            }
            else
            {
                // Falls nichts gültiges eingegeben wurde, setze den Standardwert 50
                cycles = 4;
            }

            // Standardwert für distractionMode
            string distractionMode = "Full-blocking mode";

            // Prüfe zuerst, ob die TextBox (`SelectedText`) einen gültigen Wert enthält
            if (!string.IsNullOrWhiteSpace(SelectedText.Text))
            {
                distractionMode = SelectedText.Text; // Wert aus der TextBox übernehmen
            }
            else if (CategoryList.SelectedItem is ListBoxItem selectedItem)
            {
                distractionMode = selectedItem.Content.ToString(); // Falls in der ListBox etwas gewählt wurde
            }
            else
            {
                // Falls nichts gültiges eingegeben wurde, setze den Standardwert
                distractionMode = "Full-blocking mode";
            }

            int warningSeconds;

            // Prüfe zuerst, ob die TextBox (`SelectedText1`) eine gültige Zahl enthält
            if (int.TryParse(SelectedText4.Text, out warningSeconds))
            {
                // Wert aus der TextBox wurde erfolgreich als Ganzzahl geparst
            }
            else if (CategoryList4.SelectedItem is ListBoxItem selectedItem &&
                     int.TryParse(selectedItem.Content.ToString(), out warningSeconds))
            {
                // Falls die TextBox leer ist, prüfe ob ein Wert in der ListBox ausgewählt wurde
            }
            else
            {
                MessageBox.Show("THIS", "Title", MessageBoxButton.OK, MessageBoxImage.Information);

                // Falls nichts gültiges eingegeben wurde, setze den Standardwert 50
                warningSeconds = 10;
            }

            // Standardwert für distractionMode
            string mascotVisible = "Yes";

            // Prüfe zuerst, ob die TextBox (`SelectedText`) einen gültigen Wert enthält
            if (!string.IsNullOrWhiteSpace(SelectedText5.Text))
            {
                mascotVisible = SelectedText5.Text; // Wert aus der TextBox übernehmen
            }
            else if (CategoryList5.SelectedItem is ListBoxItem selectedItem)
            {
                mascotVisible = selectedItem.Content.ToString(); // Falls in der ListBox etwas gewählt wurde
            }
            else
            {
                // Falls nichts gültiges eingegeben wurde, setze den Standardwert
                mascotVisible = "Yes";
            }

            bool wordsOfAffirmation = WordsOfAffirmationCheckBox.IsChecked ?? false;
            bool insultingWords = InsultingWordsCheckBox.IsChecked ?? false;

            // Anzeige der Werte in einer MessageBox
            MessageBox.Show($"Focus Period: {focusPeriod} minutes\n" +
                            $"Break Period: {breakPeriod} minutes\n" +
                            $"Cycles: {cycles}\n" +
                            $"Distraction Mode: {distractionMode}\n" +
                            $"Warning Seconds: {warningSeconds}\n" +
                            $"Mascot Visible: {mascotVisible}\n" +
                            $"Words of Affirmation: {wordsOfAffirmation}\n" +
                            $"Insulting Words: {insultingWords}",
                            "Current Settings",
                            MessageBoxButton.OK,
                            MessageBoxImage.Information);

            tmpSession = new Session(focusPeriod, breakPeriod, cycles, distractionMode, mascotVisible, wordsOfAffirmation, insultingWords);
            this.NavigationService.Navigate(tmpSession);
        }

        public static Session getSessionInstance() {
            return tmpSession;
        }

        public static void SetSessionInstance(Session newSession)
        {
            tmpSession = newSession;
        }

        private void ComboBox_PreviewTextInput(object sender, TextCompositionEventArgs e)
        {
            e.Handled = !int.TryParse(e.Text, out _);
        }

        private void ComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {

        }


        private void SelectedTextBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            TextBox textBox = sender as TextBox;
            if (textBox == null) return;

            string input = textBox.Text;

            // Erlaubt nur numerische Eingaben (positive Ganzzahlen) und begrenzt die Länge auf 3 Zeichen
            if (!Regex.IsMatch(input, @"^\d*$"))
            {
                int cursorPos = textBox.SelectionStart - 1; // Cursor-Position speichern
                textBox.Text = Regex.Replace(input, @"\D", ""); // Alle nicht-numerischen Zeichen entfernen
                textBox.SelectionStart = Math.Max(cursorPos, 0); // Cursor wieder an die ursprüngliche Stelle setzen
            }

            // Maximal 3 Zeichen erlauben
            if (textBox.Text.Length > 3)
            {
                int cursorPos = textBox.SelectionStart - 1; // Cursor-Position speichern
                textBox.Text = textBox.Text.Substring(0, 3); // Kürzt den Text auf 3 Zeichen
                textBox.SelectionStart = Math.Max(cursorPos, 0); // Cursor-Position wieder setzen
            }
        }

        private void TogglePopup(object sender, MouseButtonEventArgs e)
        {
            // Popup umschalten
            PopupMenu.IsOpen = !PopupMenu.IsOpen;

            // Wenn das Popup geöffnet wird, registriere das globale Klick-Event
            if (PopupMenu.IsOpen)
            {
                this.PreviewMouseDown += ClosePopupOnClickOutside;
            }
        }

        private void CategoryList_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (CategoryList.SelectedItem is ListBoxItem selectedItem)
            {
                SelectedText.Text = selectedItem.Content.ToString();
                PopupMenu.IsOpen = false; // Popup schließen nach Auswahl
                this.PreviewMouseDown -= ClosePopupOnClickOutside; // Event entfernen

                if (SelectedText.Text.Contains("seconds warning mode"))
                {
                    SecondsWarningPanel.Visibility = Visibility.Visible;

                    // Setze einen Standardwert für Warning Seconds, falls kein Wert vorhanden ist
                    if (string.IsNullOrWhiteSpace(SelectedText.Text))
                    {
                        SelectedText.Text = "10"; // Default-Wert für Warning Seconds
                    }
                }
                else
                {
                    SecondsWarningPanel.Visibility = Visibility.Collapsed;
                }
            }
        }

        private void ClosePopupOnClickOutside(object sender, MouseButtonEventArgs e)
        {
            if (!PopupMenu.IsMouseOver && !DropdownBorder.IsMouseOver)
            {
                PopupMenu.IsOpen = false;
                this.PreviewMouseDown -= ClosePopupOnClickOutside; // Event entfernen
            }
        }

        private void TogglePopup1(object sender, MouseButtonEventArgs e)
        {
            // Popup umschalten
            PopupMenu1.IsOpen = !PopupMenu1.IsOpen;

            // Wenn das Popup geöffnet wird, registriere das globale Klick-Event
            if (PopupMenu1.IsOpen)
            {
                this.PreviewMouseDown += ClosePopupOnClickOutside1;
            }
        }

        private void CategoryList_SelectionChanged1(object sender, SelectionChangedEventArgs e)
        {
            if (CategoryList1.SelectedItem is ListBoxItem selectedItem)
            {
                SelectedText1.Text = selectedItem.Content.ToString();
                PopupMenu1.IsOpen = false; // Popup schließen nach Auswahl
                this.PreviewMouseDown -= ClosePopupOnClickOutside1; // Event entfernen
            }
        }

        



        private void ClosePopupOnClickOutside1(object sender, MouseButtonEventArgs e)
        {
            if (!PopupMenu1.IsMouseOver && !DropdownBorder1.IsMouseOver)
            {
                PopupMenu1.IsOpen = false;
                this.PreviewMouseDown -= ClosePopupOnClickOutside1; // Event entfernen
            }
        }

        private void TogglePopup2(object sender, MouseButtonEventArgs e)
        {
            // Popup umschalten
            PopupMenu2.IsOpen = !PopupMenu2.IsOpen;

            // Wenn das Popup geöffnet wird, registriere das globale Klick-Event
            if (PopupMenu2.IsOpen)
            {
                this.PreviewMouseDown += ClosePopupOnClickOutside2;
            }
        }

        private void CategoryList_SelectionChanged2(object sender, SelectionChangedEventArgs e)
        {
            if (CategoryList2.SelectedItem is ListBoxItem selectedItem)
            {
                SelectedText2.Text = selectedItem.Content.ToString();
                PopupMenu2.IsOpen = false; // Popup schließen nach Auswahl
                this.PreviewMouseDown -= ClosePopupOnClickOutside2; // Event entfernen
            }
        }


        private void ClosePopupOnClickOutside2(object sender, MouseButtonEventArgs e)
        {
            if (!PopupMenu2.IsMouseOver && !DropdownBorder2.IsMouseOver)
            {
                PopupMenu2.IsOpen = false;
                this.PreviewMouseDown -= ClosePopupOnClickOutside2; // Event entfernen
            }
        }

        private void TogglePopup3(object sender, MouseButtonEventArgs e)
        {
            // Popup umschalten
            PopupMenu3.IsOpen = !PopupMenu3.IsOpen;

            // Wenn das Popup geöffnet wird, registriere das globale Klick-Event
            if (PopupMenu3.IsOpen)
            {
                this.PreviewMouseDown += ClosePopupOnClickOutside3;
            }
        }

        private void CategoryList_SelectionChanged3(object sender, SelectionChangedEventArgs e)
        {
            if (CategoryList3.SelectedItem is ListBoxItem selectedItem)
            {
                SelectedText3.Text = selectedItem.Content.ToString();
                PopupMenu3.IsOpen = false; // Popup schließen nach Auswahl
                this.PreviewMouseDown -= ClosePopupOnClickOutside3; // Event entfernen
            }
        }



        private void ClosePopupOnClickOutside3(object sender, MouseButtonEventArgs e)
        {
            if (!PopupMenu3.IsMouseOver && !DropdownBorder3.IsMouseOver)
            {
                PopupMenu3.IsOpen = false;
                this.PreviewMouseDown -= ClosePopupOnClickOutside3; // Event entfernen
            }
        }

        private void TogglePopup4(object sender, MouseButtonEventArgs e)
        {
            // Popup umschalten
            PopupMenu4.IsOpen = !PopupMenu4.IsOpen;

            // Wenn das Popup geöffnet wird, registriere das globale Klick-Event
            if (PopupMenu4.IsOpen)
            {
                this.PreviewMouseDown += ClosePopupOnClickOutside4;
            }
        }

        private void CategoryList_SelectionChanged4(object sender, SelectionChangedEventArgs e)
        {
            if (CategoryList4.SelectedItem is ListBoxItem selectedItem)
            {
                SelectedText4.Text = selectedItem.Content.ToString();
                PopupMenu4.IsOpen = false; // Popup schließen nach Auswahl
                this.PreviewMouseDown -= ClosePopupOnClickOutside4; // Event entfernen
            }
        }



        private void ClosePopupOnClickOutside4(object sender, MouseButtonEventArgs e)
        {
            if (!PopupMenu4.IsMouseOver && !DropdownBorder4.IsMouseOver)
            {
                PopupMenu4.IsOpen = false;
                this.PreviewMouseDown -= ClosePopupOnClickOutside4; // Event entfernen
            }
        }

        private void TogglePopup5(object sender, MouseButtonEventArgs e)
        {
            // Popup umschalten
            PopupMenu5.IsOpen = !PopupMenu5.IsOpen;

            // Wenn das Popup geöffnet wird, registriere das globale Klick-Event
            if (PopupMenu5.IsOpen)
            {
                this.PreviewMouseDown += ClosePopupOnClickOutside5;
            }
        }

        private void CategoryList_SelectionChanged5(object sender, SelectionChangedEventArgs e)
        {
            if (CategoryList5.SelectedItem is ListBoxItem selectedItem)
            {
                SelectedText5.Text = selectedItem.Content.ToString();
                PopupMenu5.IsOpen = false; // Popup schließen nach Auswahl
                this.PreviewMouseDown -= ClosePopupOnClickOutside5; // Event entfernen
            }

            if (MotivationOptionsPanel == null) return;

            // MotivationOptionsPanel wird sichtbar oder verborgen
            if (SelectedText5.Text == "No")
            {
                MotivationOptionsPanel.Visibility = Visibility.Collapsed;
                WordsOfAffirmationCheckBox.IsChecked = false;
                InsultingWordsCheckBox.IsChecked = false;
            }
            else
            {
                MotivationOptionsPanel.Visibility = Visibility.Visible;
            }
        }



        private void ClosePopupOnClickOutside5(object sender, MouseButtonEventArgs e)
        {
            if (!PopupMenu5.IsMouseOver && !DropdownBorder5.IsMouseOver)
            {
                PopupMenu5.IsOpen = false;
                this.PreviewMouseDown -= ClosePopupOnClickOutside4; // Event entfernen
            }
        }


        private void Button_Click_2(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Distractions());
        }

        private void Button_Click_3(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new ProgramsList());
        }

        private void Button_Click_4(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Overview());
        }

        private void Button_Click_5(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Statistics());
        }

        private void Button_Click_6(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Abonnement());
        }

        private void Button_Click_7(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Contact());
        }

        private void Button_Click_8(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Settings());
        }

        private void BurgerMenuButton_Click(object sender, RoutedEventArgs e)
        {
            MenuPanel.Visibility = MenuPanel.Visibility == Visibility.Visible ? Visibility.Collapsed : Visibility.Visible;
        }

    }
}
