﻿using InnoLabProjektDektopApp.Screens.Regulaer;
using InnoLabProjektDektopApp.Services;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Threading;

namespace InnoLabProjektDektopApp
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class Session : Page
    {
        private int focusPeriod;
        private int breakPeriod;
        private int cycles;
        private string distractionMode;
        private string mascotVisible;
        private bool wordsOfAffirmation;
        private bool insultingWords;

        private bool isBreakPeriod = false; // Speichert, ob wir in einer Pause sind

        private Mascott mascott;

        private DispatcherTimer timer;
        private int maxTime;
        private int seconds;
        private int step = -1; //Indicates whether the timer is running (-1) or paused (0)
        private int sessions;
        private int currentSession = 1; //Tracks which session is currently running
        private ProcessMonitor processMonitor = App.GetProcessMonitor();

        public Session(int focusPeriod,
        int breakPeriod,
        int cycles,
        string distractionMode,
        string mascotVisible,
        bool wordsOfAffirmation,
        bool insultingWords)
        {
            InitializeComponent();
            this.focusPeriod = focusPeriod;
            this.breakPeriod = breakPeriod * 60;
            this.cycles = cycles;
            this.distractionMode = distractionMode;
            this.mascotVisible = mascotVisible;
            this.wordsOfAffirmation = wordsOfAffirmation;
            this.insultingWords = insultingWords;

            this.maxTime = focusPeriod * 60; //todo: multiply with 60 later
            this.seconds = this.maxTime;
            this.sessions = cycles;

            timer = new DispatcherTimer();
            timer.Interval = TimeSpan.FromSeconds(1);
            timer.Tick += Timertick;
            timer.Start();

            mascott = new Mascott();
            mascott.Show();

            processMonitor.StartMonitoring();
            CreateCycleIndicators(); // Kreise erstellen
            UpdateTexts();

            // Subscribe to the events of the process monitor
            processMonitor.MonitorCycleStarted += HandleMonitorCycleStarted;
            processMonitor.MonitorPaused += HandleMonitorPaused;
            processMonitor.MonitorResumed += HandleMonitorResumed;
            processMonitor.MonitorBreakStarted += HandleMonitorBreakStarted;
            processMonitor.MonitorSessionFinished += HandleMonitorSessionFinished;
        }

        private void HandleMonitorCycleStarted(object sender, EventArgs e)
        {
            seconds = maxTime; // Zeit für die Fokusperiode
            isBreakPeriod = false; // Zurück zum Fokus
            currentSession++; // Gehe zum nächsten Zyklus
            PlayPauseButtonText.Text = "Pause";
        }

        private void HandleMonitorPaused(object sender, EventArgs e)
        {
            timer.Stop(); // Stop the time
            step = 0; // Stop counting down
            PlayPauseButtonText.Text = "Continue";
        }

        private void HandleMonitorResumed(object sender, EventArgs e)
        {
            timer.Start();
            step = -1; // Set step to countdown
            PlayPauseButtonText.Text = "Pause";
        }

        private void HandleMonitorBreakStarted(object sender, EventArgs e)
        {
            PlayPauseButtonText.Text = "Skip Break";
            seconds = breakPeriod; // Zeit für die Pause
            isBreakPeriod = true; // Wechsel in den Pausenmodus
        }

        private void HandleMonitorSessionFinished(object sender, EventArgs e)
        {
            timer.Stop();
            string jsonpath = ((ProcessMonitor)sender).lastSessionInfoFilePath;
            NavigationService.Navigate(new SessionStatistics(jsonpath));
            // MessageBox.Show("All sessions completed!", "Info", MessageBoxButton.OK, MessageBoxImage.Information);
        }



        private void Timertick(object sender, EventArgs e)
        {
            seconds += step; // Reduziere Zeit, wenn der Timer läuft
            
            UpdateTexts(); // Aktualisiere die UI

            // Fortschrittsanzeige nur während der Fokusperiode aktualisieren

            CreateCycleIndicators(); // Fortschritt für Fokus-Perioden anzeigen

            if (seconds <= 0) // Wenn die Zeit abgelaufen ist
            {
                if (currentSession >= sessions) // Wenn alle Zyklen abgeschlossen sind
                {
                    processMonitor.FinishSession();
                    return;
                }
                if (isBreakPeriod) // Wenn wir in einer Pause sind
                {
                    processMonitor.EndBreak();
                }
                else // Wenn wir im Fokus sind
                {
                    processMonitor.StartBreak();
                }
            }
        }

        public void SetTime(int minutes, int seconds)
        {
            if (minutes < 0 || minutes > maxTime / 60 || seconds < 0 || seconds > maxTime % 60) return;
            this.seconds = minutes * 60 + seconds;
            UpdateTexts();
        }

        private void UpdateTexts()
        {
            Clock.Text = seconds / 60 + ":" + (seconds % 60 < 10 ? "0" : "") + seconds % 60;

            if (isBreakPeriod)
            {
                Title.Text = $"Break Session {currentSession} of {sessions}";
            }
            else
            {
                Title.Text = $"Focus Session {currentSession} of {sessions}";
            }
        }

        private void PlayPause_Click(object sender, RoutedEventArgs e)
        {
            if (step < 0)
            {
                if (isBreakPeriod)
                {
                    processMonitor.EndBreak();
                }
                else
                {
                    processMonitor.StartPause();
                }
            }
            else
            {
                processMonitor.EndPause();
            }
        }

        private void CreateCycleIndicators()
        {
            // Clear existing indicators
            CyclesIndicatorPanel.Children.Clear();

            for (int i = 0; i < cycles; i++)
            {
                if (i + 1 == currentSession) // Highlight the current session with a ProgressBar
                {
                    if (isBreakPeriod) // Während der BreakPeriod
                    {
                        // Zeige ausgefüllten Kreis für die aktuelle Session
                        Ellipse filledCircle = new()
                        {
                            Width = 20,
                            Height = 20,
                            Margin = new Thickness(10),
                            Fill = new SolidColorBrush(Color.FromRgb(173, 216, 230)), // Ausgefüllter Kreis
                        };
                        CyclesIndicatorPanel.Children.Add(filledCircle);
                    }
                    else // Während der FocusPeriod
                    {
                        // Zeige die ProgressBar für die aktuelle Session
                        Grid cycleGrid = new()
                        {
                            Width = 50,
                            Height = 20, // Höhe des erweiterten Kreises
                            Margin = new Thickness(10),
                        };

                        // ProgressBar
                        Rectangle progressBar = new()
                        {
                            Width = 50, // Gleiche Breite wie der Hintergrund
                            Height = 20, // Gleiche Höhe wie der Hintergrund
                            Fill = GradientGenerator.GenerateTwoColorBrush(
                                Color.FromRgb(173, 216, 230),
                                Color.FromRgb(238, 238, 238),
                                1 - (seconds / (double)maxTime)
                            ),
                            RadiusX = 10,
                            RadiusY = 10,
                            HorizontalAlignment = HorizontalAlignment.Left,
                        };

                        cycleGrid.Children.Add(progressBar); // ProgressBar hinzufügen
                        CyclesIndicatorPanel.Children.Add(cycleGrid);
                    }
                }
                else
                {
                    // Standardkreis für abgeschlossene oder zukünftige Zyklen
                    Ellipse cycleIndicator = new()
                    {
                        Width = 20,
                        Height = 20,
                        Margin = new Thickness(10),
                        Fill = i < currentSession ? new SolidColorBrush(Color.FromRgb(72, 98, 132)) : Brushes.LightGray,
                    };

                    CyclesIndicatorPanel.Children.Add(cycleIndicator);
                }
            }
        }

        private void DiscardSession_Click(object sender, RoutedEventArgs e)
        {
            // Neues Fenster für die Auswahl des Abbruchgrunds erstellen
            Window reasonWindow = new()
            {
                Title = "Warum beenden Sie die Sitzung?",
                Width = 600,
                Height = 200,
                WindowStartupLocation = WindowStartupLocation.CenterScreen,
                ResizeMode = ResizeMode.NoResize
            };

            // Haupt-StackPanel für die Radiobuttons und den OK-Button
            StackPanel stackPanel = new()
            {
                Margin = new Thickness(10)
            };

            // Radiobuttons für die Gründe mit explizitem TextBlock zur Steuerung der Textfarbe
            RadioButton reason1 = new()
            {
                Content = new TextBlock
                {
                    Text = "Ich habe mich dazu entschieden, frühzeitig zu beenden (wird in die Statistik mit aufgenommen).",
                    Foreground = Brushes.Black // Hier wird die Textfarbe korrekt gesetzt
                },
                Margin = new Thickness(5),
                IsChecked = true,
                Style = null
            };

            RadioButton reason2 = new()
            {
                Content = new TextBlock
                {
                    Text = "Mir ist etwas sehr Wichtiges dazwischengekommen, was ich nicht verschieben konnte.",
                    Foreground = Brushes.Black // Hier wird die Textfarbe korrekt gesetzt
                },
                Margin = new Thickness(5),
                Style = null
            };

            // OK-Button mit explizitem TextBlock für die Textfarbe
            Button okButton = new()
            {
                Content = new TextBlock
                {
                    Text = "Ok",
                    Foreground = Brushes.Black // Hier wird die Textfarbe korrekt gesetzt
                },
                Margin = new Thickness(5),
                Width = 80,
                HorizontalAlignment = HorizontalAlignment.Right
            };

            okButton.Click += (s, args) =>
            {
                string selectedReason = reason1.IsChecked == true ? "Ich habe mich dazu entschieden, frühzeitig zu beenden" :
                                        reason2.IsChecked == true ? "Mir ist etwas sehr Wichtiges dazwischengekommen, was ich nicht verschieben konnte." :
                                          "Kein Grund ausgewählt";

                MessageBox.Show($"Abbruchgrund: {selectedReason}", "Sitzung beendet", MessageBoxButton.OK, MessageBoxImage.Information);
                reasonWindow.Close();
                processMonitor.FinishSession();
            };

            // Radiobuttons und Button zum StackPanel hinzufügen
            stackPanel.Children.Add(new TextBlock { Text = "Wählen Sie den Grund für den Abbruch aus:", Margin = new Thickness(5), Foreground= Brushes.Black });
            stackPanel.Children.Add(reason1);
            stackPanel.Children.Add(reason2);
            stackPanel.Children.Add(okButton);

            // StackPanel als Content des Fensters setzen
            reasonWindow.Content = stackPanel;

            // Fenster anzeigen
            reasonWindow.Show();
        }

        public DateTime TimeLeft()
        {
            return DateTime.Now.AddSeconds(maxTime - seconds);
        }

        private void Page_Unloaded(object sender, RoutedEventArgs e)
        {
            timer.Stop();
            timer.Tick -= Timertick;
            processMonitor.MonitorCycleStarted -= HandleMonitorCycleStarted;
            processMonitor.MonitorPaused -= HandleMonitorPaused;
            processMonitor.MonitorResumed -= HandleMonitorResumed;
            processMonitor.MonitorBreakStarted -= HandleMonitorBreakStarted;
            processMonitor.MonitorSessionFinished -= HandleMonitorSessionFinished;
            mascott.Close();
        }

        /*private void Button_Click_1(object sender, RoutedEventArgs e)
        {
            mascott.emotionUp_();
            ProcessMonitor.tmpStage++;
            StageText.Text = ProcessMonitor.tmpStage.ToString();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            mascott.emotionDown_();
            ProcessMonitor.tmpStage--;
            StageText.Text = ProcessMonitor.tmpStage.ToString();
        }*/

        private void Button_Click_2(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Distractions());
        }

        private void Button_Click_3(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new ProgramsList());
        }

        private void Button_Click_4(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Overview());
        }

        private void Button_Click_5(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Statistics());
        }

        private void Button_Click_6(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Abonnement());
        }

        private void Button_Click_7(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Contact());
        }

        private void Button_Click_8(object sender, RoutedEventArgs e)
        {
            this.NavigationService.Navigate(new Settings());
        }

        private void BurgerMenuButton_Click(object sender, RoutedEventArgs e)
        {
            MenuPanel.Visibility = MenuPanel.Visibility == Visibility.Visible ? Visibility.Collapsed : Visibility.Visible;
        }
    }
}

public static class GradientGenerator
{
    public static Brush GenerateTwoColorBrush(Color color1, Color color2, double ratio)
    {
        GradientStopCollection collection =
        [
            new GradientStop(color1, 0),
            new GradientStop(color1, ratio),
            new GradientStop(color2, ratio),
            new GradientStop(color2, 1.0),
        ];

        LinearGradientBrush brush = new(collection)
        {
            StartPoint = new Point(0, 0),
            EndPoint = new Point(1, 0)
        };

        return brush;
    }
}
