﻿using InnoLabProjektDektopApp.Services;
using System.Diagnostics;
using System.IO;
using System.Text.Json;
using System.Windows;
using System.Windows.Input;
using System.Windows.Interop;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Threading;

namespace InnoLabProjektDektopApp.Screens.Regulaer
{
    /// <summary>
    /// Interaction logic for Mascott.xaml
    /// </summary>
    public partial class Mascott : Window
    {
        private DispatcherTimer frameTimer;
        private DispatcherTimer animationTimer;
        private int frameCounter = 0;
        private int distractionStage = 4;
        private string framePath = "";
        private int oldDistractionStage = 4;
        private string animationDirection = "Up";

        ProcessMonitor processMonitor;

        public Mascott()
        {

            if (!mascottVisible())
            {
                MascottImage.Visibility = Visibility.Hidden;
                return;
            }

            InitializeComponent();
            emotionUp_();

            processMonitor = App.GetProcessMonitor();
            this.Left = -30; //SystemParameters.PrimaryScreenWidth - this.Width;
            this.Top = SystemParameters.PrimaryScreenHeight - this.Height - 30;

            animationTimer = new DispatcherTimer();
            animationTimer.Interval = TimeSpan.FromMilliseconds(4000);
            animationTimer.Tick += animationTick;
            animationTimer.Start();

            RenderOptions.SetBitmapScalingMode(MascottImage, BitmapScalingMode.LowQuality);
            RenderOptions.ProcessRenderMode = RenderMode.Default;

        }

        private void animationTick(object sender, EventArgs e)
        {
            DateTime timeLeft = Overview.getSessionInstance().TimeLeft();
            int processMonitorStage = processMonitor.CalculateCurrentDistractionStage(DateTime.Now);

            if (processMonitorStage == oldDistractionStage)
            {
                // Counterxd.Text = "x: " + processMonitorStage.ToString();
                return;
            }
            else if (processMonitorStage < oldDistractionStage)
            {
                emotionUp_();
                // Counterxd.Text = "d: " + processMonitorStage.ToString();
            }
            else if (processMonitorStage > oldDistractionStage)
            {
                emotionDown_();
                // Counterxd.Text = "u: " + processMonitorStage.ToString();
            }
            oldDistractionStage = processMonitorStage;
        }

        public void emotionUp_()
        {
            if (animationDirection == "Down") distractionStage--;
            if (distractionStage < 1)
            {
                distractionStage = 1;
                return;
            }
            animationDirection = "Down";
            frameCounter = 1;

            // Counterxd.Text = distractionStage.ToString();
            frameTimer = new DispatcherTimer();
            frameTimer.Interval = TimeSpan.FromMilliseconds(42);
            frameTimer.Tick += frameTick;
            frameTimer.Start();
        }

        public void emotionDown_()
        {
            if (animationDirection == "Up") distractionStage++;
            if (distractionStage > 7)
            {
                distractionStage = 7;
                return;
            }
            animationDirection = "Up";
            frameCounter = 1;

            // Counterxd.Text = distractionStage.ToString();
            frameTimer = new DispatcherTimer();
            frameTimer.Interval = TimeSpan.FromMilliseconds(42);
            frameTimer.Tick += frameTick;
            frameTimer.Start();
        }

        private void frameTick(object sender, EventArgs e)
        {
            framePath = $"pack://application:,,,/Assets/MascottAnimation/{animationDirection}/{distractionStage}/frame{frameCounter}.png";

            bool successfullySet = setFrame();

            if (!successfullySet)
            {
                frameTimer.Stop();
                //ellipse1.Fill = Brushes.Red;
                Debug.WriteLine(new Uri($"pack://application:,,,/Assets/MascottAnimation/{animationDirection}/{distractionStage}/frame{frameCounter}.png"));

            }

            frameCounter++;
        }

        private bool setFrame() //returns, if the frame was successfully set
        {
            try
            {
                MascottImage.Source = new BitmapImage(new Uri(framePath));
            }
            catch (Exception)
            {
                return false;
            }

            return true;
        }

        private bool mascottVisible()
        {
            String profile = "profile1";
            String SettingsFilePath = System.IO.Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "settings.json");

            if (File.Exists(SettingsFilePath))
            {
                string jsonContent = File.ReadAllText(SettingsFilePath);
                var settings = JsonSerializer.Deserialize<Dictionary<string, JsonElement>>(jsonContent);

                if (settings != null && settings.ContainsKey(profile))
                {
                    var profileSettings = settings[profile];

                    if (profileSettings.TryGetProperty("mascotVisibility", out var mascotVisibilityElement))
                    {

                        string mascotVisibility = mascotVisibilityElement.GetString();
                        if (mascotVisibility.Equals("Yes"))
                        {
                            return true;
                        }
                    }
                }
            }

            return false;
        }

        private void Window_MouseDown(object sender, MouseButtonEventArgs e)
        {
            if (e.ChangedButton == MouseButton.Left)
                this.DragMove();
        }

        private void Window_LocationChanged(object sender, EventArgs e)
        {
            // Prevent the window from moving too close to the edges
            if (this.Left < -30)
                this.Left = -30;
            if (this.Top < 0)
                this.Top = 0;
            if (this.Left + this.Width > SystemParameters.PrimaryScreenWidth)
                this.Left = SystemParameters.PrimaryScreenWidth - this.Width;
            if (this.Top + this.Height > SystemParameters.PrimaryScreenHeight - 30)
                this.Top = SystemParameters.PrimaryScreenHeight - this.Height - 30;
        }

        private void Window_Closing(object sender, System.ComponentModel.CancelEventArgs e)
        {
            // processMonitor.FinishSession();
        }
    }
}
